import { Component, ChangeDetectionStrategy, ElementRef, Input, Output, EventEmitter } from '@angular/core';
import * as echarts from 'echarts';
var EChartsComponent = (function () {
    // event: 'click'、'dblclick'、'mousedown'、'mousemove'、'mouseup'、'mouseover'、'mouseout'
    function EChartsComponent(elementRef) {
        this.elementRef = elementRef;
        this.width = '100%';
        this.height = '400px';
        this.chartCreated = new EventEmitter();
    }
    EChartsComponent.prototype.ngAfterViewInit = function () {
        this.chart = echarts.init(this.elementRef.nativeElement, this.theme);
        this.updateChartData(this.options);
        this.chartCreated.emit(this);
    };
    EChartsComponent.prototype.ngOnChanges = function (changes) {
        if (this.chart && changes['options']) {
            var currentValue = changes['options'].currentValue;
            this.updateChartData(currentValue);
        }
    };
    EChartsComponent.prototype.ngOnDestroy = function () {
        if (this.chart) {
            this.chart.dispose();
        }
    };
    EChartsComponent.prototype.updateChartData = function (options, notMerge, lazyUpdate) {
        if (options) {
            this.chart.setOption(options, notMerge, lazyUpdate);
        }
    };
    EChartsComponent.prototype.resize = function () {
        this.chart.resize();
    };
    EChartsComponent.prototype.showLoading = function (type, opts) {
        this.chart.showLoading(type, opts);
    };
    EChartsComponent.prototype.hideLoading = function () {
        this.chart.hideLoading();
    };
    EChartsComponent.prototype.getDataURL = function (opts) {
        return this.chart.getDataURL(opts);
    };
    EChartsComponent.decorators = [
        { type: Component, args: [{
                    selector: 're-echarts',
                    template: '',
                    host: {
                        '[style.display]': '"block"',
                        '[style.width]': 'width',
                        '[style.height]': 'height'
                    },
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    exportAs: 'chart'
                },] },
    ];
    /** @nocollapse */
    EChartsComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    EChartsComponent.propDecorators = {
        "options": [{ type: Input },],
        "width": [{ type: Input },],
        "height": [{ type: Input },],
        "theme": [{ type: Input },],
        "chartCreated": [{ type: Output },],
    };
    return EChartsComponent;
}());
export { EChartsComponent };
//# sourceMappingURL=echarts.component.js.map